<template>
  <div class="section-main-container layout-padding">
    <div class="section-main-padding layout-padding-auto layout-padding-view">
      <div class="section-user-search mb15">
        <el-form :inline="true" :model="source.searchInfo" class="demo-form-inline" label-position="left" size="default"
          @submit.prevent>
          <el-form-item label="公司名称">
            <el-input v-model="source.searchInfo.name" placeholder="请输入公司名称" clearable @keyup.enter="getTableData"
              style="max-width: 180px" />
          </el-form-item>
          <el-form-item label="联动值" v-if="!showJinCheng">
            <el-select v-model="source.searchInfo.hasPoints">
              <el-option label="全部" :value="null"></el-option>
              <el-option label="已购买" :value="true"></el-option>
              <el-option label="未购买" :value="false"></el-option>
            </el-select>
          </el-form-item>
          <el-form-item label="监管机构">
						<el-cascader v-model="source.superviseDepartIdArr" :options="source.searchInfo.options"
							:props="customProps" collapse-tags collapse-tags-tooltip :show-all-levels="false" clearable
							ref="myCascader" />
					</el-form-item>
          <!-- <el-form-item label="调度台">
            <el-select v-model="source.searchInfo.hasDesk">
              <el-option label="全部" :value="null"></el-option>
              <el-option label="已购买" :value="true"></el-option>
              <el-option label="未购买" :value="false"></el-option>
            </el-select>
          </el-form-item> -->
          <el-form-item label="经纬度坐标">
            <el-select v-model="source.searchInfo.hasLocation">
              <el-option label="全部" :value="null"></el-option>
              <el-option label="已设置" :value="true"></el-option>
              <el-option label="未设置" :value="false"></el-option>
            </el-select>
          </el-form-item>
          <el-form-item>
            <el-button type="primary" @click="getTableData">查询</el-button>
            <el-button type="default" @click="resetgetTableData">重置</el-button>
						<el-button type="primary" @click="exportData">导出</el-button>
          </el-form-item>
        </el-form>
      </div>
      <el-table :data="source.companyInfoList" v-loading="source.loading" style="width: 100%">
        <el-table-column type="index" width="80" label="序号" align="center" />
        <el-table-column prop="name" label="公司名称" align="center" show-overflow-tooltip></el-table-column>
        <el-table-column prop="legal" label="法人/负责人" align="center" show-overflow-tooltip></el-table-column>
        <el-table-column prop="legalContact" label="法人/负责人手机号" align="center" show-overflow-tooltip></el-table-column>
        <el-table-column prop="points" label="联动值余额" align="center" show-overflow-tooltip v-if="!showJinCheng"></el-table-column>
        <el-table-column prop="countOfDesk" label="调度台数量" align="center" show-overflow-tooltip v-if="!showJinCheng"></el-table-column>
        <el-table-column prop="callerTencentUserId" label="是否设置经纬度坐标" align="center" show-overflow-tooltip>
          <template #default="scope">
            <span>{{ scope.row.hasLonLat ? '已设置' : '未设置' }}</span>
          </template>
        </el-table-column>
        <el-table-column prop="countOfStation" label="驻勤点数" align="center" show-overflow-tooltip></el-table-column>
        <el-table-column prop="countOfSecurityMan" label="驻勤人员数" align="center" show-overflow-tooltip></el-table-column>
        <el-table-column label="未激活人员" align="center" width="120">
          <template #default="scope">
            <el-button size="small" text type="primary"
              @click.prevent="checkUnactivatedSecurityGuard(scope.row.name)">查看</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="mt15"
        :pager-count="5" :page-sizes="[10, 20, 30, 100, 200, 300, 1000]" v-model:current-page="source.pageIndex"
        background v-model:page-size="source.pageSize" layout="total, sizes, prev, pager, next, jumper"
        :total="source.totalCount">
      </el-pagination>
    </div>
  </div>
</template>

<script setup lang="ts">
import { reactive, onMounted, ref, computed} from 'vue';
import { ElMessage } from 'element-plus';
import { ConfigApi } from '/@/api/api';
import router from '/@/router/index';
import { Session } from '/@/utils/storage';

const showJinCheng = computed(() => {
    return import.meta.env.VITE_SHOW_JINCHENG_PROJECT === 'true'
})
// 定义变量内容
const source = reactive({
  loading: false,
  companyInfoList: [],
  searchInfo: {
    name: '',
    hasPoints: null,
    // hasDesk: null,
    hasLocation: null,
	  options: [],
	  superviseDepartIds: [],
  },
  superviseDepartIdArr: [] as string[],
  totalCount: 0,
  pageIndex: 1,
  pageSize: 10,
  pageCount: null,
 
});


// 定义变量内容
const customProps = {
	multiple: true,// 启用多选
	checkStrictly: false,//父子节点不互相关联
	emitPath: true,//若设置 false，则只返回该节点的值
	value: 'code',//自定义当前数组的键名 - value
	label: 'name', // 自定义当前数组的键名 - label 
}

const myCascader = ref();


// 页面加载时
onMounted(() => {
  searchDeparts();
  // getTableData();
});

// 初始化表格数据
const getTableData = () => {
  source.loading = true;

  let Depstr: [] = []
	if (myCascader.value.getCheckedNodes().length) {
		myCascader.value.getCheckedNodes().forEach((item: { value: any; }) => Depstr.push(item.value))
	}
	source.searchInfo.superviseDepartIds = Depstr

  let params = {
    pageIndex: source.pageIndex,
    pageSize: source.pageSize,
    name: source.searchInfo.name,
    hasPoints: source.searchInfo.hasPoints,
    // hasDesk: source.searchInfo.hasDesk,
    hasLocation: source.searchInfo.hasLocation,
    superviseDepartIds: source.searchInfo.superviseDepartIds || [],
    deskTypes: Session.get('platform')==='2' ? ['Proprietor'] : Session.get('platform')==='3' ? ["TemporarySecurity"] : ['Normal']
  };
  ConfigApi().companyInfoSearchApi(params).then(response => {
    let { status, message, data } = response;

    if (status !== 200) {
      ElMessage.error(message);
      return;
    }

    let { pageCount, pageSize, totalCount } = data;
    source.pageSize = pageSize;
    source.pageCount = pageCount;
    source.totalCount = totalCount;
    source.companyInfoList = data.data;
  });

  setTimeout(() => {
    source.loading = false;
  }, 500);
};

// 重置查询数据
const resetgetTableData = () => {
  let obj = {
    name: '',
    hasPoints: null,
    // hasDesk: null,
    hasLocation: null,
    superviseDepartIds: [],
    options: source.searchInfo.options
  };
	source.superviseDepartIdArr = [];
  source.searchInfo = reactive(obj)
  getTableData();
};

//查询监管机构
const searchDeparts = () => {
	ConfigApi().searchDepartsApi({deskTypes: Session.get('platform')==='2' ? ['Proprietor'] : Session.get('platform')==='3' ? ["TemporarySecurity"] : ['Normal']}).then(response => {
		if (response.status == 200) {
			let data = response.data;
			console.log(data)
			source.searchInfo.options = data;
		}
	})
}

// 导出
const exportData = () => {
  const params = {
    pageIndex: source.pageIndex,
    pageSize: source.pageSize,
    name: source.searchInfo.name,
    hasPoints: source.searchInfo.hasPoints,
    // hasDesk: source.searchInfo.hasDesk,
    hasLocation: source.searchInfo.hasLocation,
    superviseDepartIds: source.searchInfo.superviseDepartIds,
    deskTypes: Session.get('platform')==='2' ? ['Proprietor'] : Session.get('platform')==='3' ? ["TemporarySecurity"] : ['Normal']
  };
	source.loading = true;
  ConfigApi().exportCompanyInfoApi(params).then(response => {
		setTimeout(() => {
	    source.loading = true;
			getTableData()
		}, 500);
		const content = response;
		const blob = new Blob([content as any]);
		const fileName = `企业信息.xlsx`;
		if ("download" in document.createElement("a")) {
			// 非IE下载
			const elink = document.createElement("a");
			elink.download = fileName;
			elink.style.display = "none";
			elink.href = URL.createObjectURL(blob);
			document.body.appendChild(elink);
			elink.click();
			URL.revokeObjectURL(elink.href); // 释放URL 对象
			document.body.removeChild(elink);
		} else {
			// IE10+下载
			navigator.msSaveBlob(blob, fileName);
		}
	}).catch((error) => { })

};


// 查看跳转未激活保安员页面
const checkUnactivatedSecurityGuard = (companyName: string): void => {
  router.push({
    path: `/dispatchView/unactivatedSecurityGuard`,
    query: {
      companyName
    }
  });
}

// 分页条数改变
const onHandleSizeChange = (val: number) => {
  source.pageSize = val;
  getTableData();
};

// 分页改变
const onHandleCurrentChange = (val: number) => {
  source.pageIndex = val;
  getTableData();
};
</script>

<style lang="scss" scoped>
.section-main-container {
  .section-main-padding {
    padding: 15px;

    .el-table {
      flex: 1;
    }

  }
}
</style>
